# mp-pyrho
[![testing](https://github.com/jmmshn/pyRho/workflows/testing/badge.svg)](https://github.com/jmmshn/pyRho/actions?query=workflow%3Atesting)
[![codecov](https://codecov.io/gh/jmmshn/pyRho/branch/master/graph/badge.svg)](https://codecov.io/gh/jmmshn/pyRho?branch=master)


[![image](https://img.shields.io/pypi/v/src.svg)](https://pypi.python.org/pypi/src)

[![image](https://img.shields.io/travis/jmmshn/src.svg)](https://travis-ci.com/jmmshn/src)

[![Documentation Status](https://readthedocs.org/projects/src/badge/?version=latest)](https://src.readthedocs.io/en/latest/?badge=latest)

[![Updates](https://pyup.io/repos/github/jmmshn/src/shield.svg)](https://pyup.io/repos/github/jmmshn/src/)

Tools for re-griding volumetric quantum chemistry data for machine-learning purposes.

- Free software: BSD license
- Documentation: <https://src.readthedocs.io>.

## Features

- Restructuring of periodic grid data (mapping from one cell representation to another)
- Upsampling of periodic grid data using fourier interpolation
- Helper functions to plot examine the data

## Credits

Jimmy-Xuan Shen: project lead
